@@ -165,8 +165,7 @@ void FileTableViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem
 
         // draw text
         QFont font = model->data(index, Qt::FontRole).value<QFont>();
-        QRect rect(option_rect.topLeft() + QPoint(kMarginLeft + 2 * 2 + kColumnIconSize, -2),
-                   size - QSize(kColumnIconSize + kMarginLeft, 0));
+        QRect rect(option_rect.topLeft() + QPoint(kMarginLeft + 2 * 2 + kColumnIconSize, -2), option_rect.size() - QSize(kColumnIconSize + kMarginLeft, 0));
         painter->setPen(kFileNameFontColor);
         painter->setFont(font);
         painter->drawText(
@@ -206,7 +205,7 @@ void FileTableViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem
 
             // Customize style using style-sheet..
             QProgressBar progressBar;
-            progressBar.resize(QSize(size.width() - 155, size.height() / 2 - 4));
+            progressBar.resize(QSize(qMax(30, option.rect.width() - 8), option.rect.height() / 2 - 4));
             progressBar.setMinimum(0);
             progressBar.setMaximum(100);
             progressBar.setValue(progress);
@@ -234,7 +233,7 @@ void FileTableViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem
             text = model->data(index, Qt::DisplayRole).toString();
         }
         QFont font = model->data(index, Qt::FontRole).value<QFont>();
-        QRect rect(option_rect.topLeft() + QPoint(9, -2), size - QSize(10, 0));
+        QRect rect = option.rect.adjusted(9, -2, -1, 0);
         painter->save();
         painter->setPen(kFontColor);
         painter->setFont(font);
@@ -263,7 +262,6 @@ FileTableView::FileTableView(QWidget *parent)
     verticalHeader()->setDefaultSectionSize(kDefaultColumnHeight);
     horizontalHeader()->setSectionResizeMode(QHeaderView::Interactive);
     horizontalHeader()->setStretchLastSection(true);
-    horizontalHeader()->setCascadingSectionResizes(true);
     horizontalHeader()->setHighlightSections(false);
     horizontalHeader()->setSortIndicatorShown(true);
     horizontalHeader()->setDefaultAlignment(Qt::AlignLeft | Qt::AlignVCenter);
@@ -912,16 +910,8 @@ void FileTableView::onOpenLocalCacheFolder()
     parent_->onOpenLocalCacheFolder();
 }
 
-void FileTableView::resizeEvent(QResizeEvent *event)
-{
-    QTableView::resizeEvent(event);
-    if (source_model_)
-        source_model_->onResize(event->size());
-}
-
 FileTableModel::FileTableModel(QObject *parent)
-    : QAbstractTableModel(parent),
-     name_column_width_(kFileNameColumnWidth)
+    : QAbstractTableModel(parent)
 {
     task_progress_timer_ = new QTimer(this);
     connect(task_progress_timer_, SIGNAL(timeout()),
@@ -992,18 +982,6 @@ QVariant FileTableModel::data(const QModelIndex & index, int role) const
 
     if (role == Qt::SizeHintRole) {
         QSize qsize(kDefaultColumnWidth, kDefaultColumnHeight);
-        switch (column) {
-        case FILE_COLUMN_NAME:
-            qsize.setWidth(name_column_width_);
-            break;
-        case FILE_COLUMN_PROGRESS:
-        case FILE_COLUMN_SIZE:
-        case FILE_COLUMN_MTIME:
-            qsize.setWidth(name_column_width_);
-        case FILE_COLUMN_MODIFIER:
-        default:
-            break;
-        }
         return qsize;
     }
 
@@ -1100,12 +1078,6 @@ QVariant FileTableModel::headerData(int section,
         return QBrush(kFontColor);
     }
 
-    if (role == Qt::SizeHintRole && section == FILE_COLUMN_NAME) {
-        if (dirents_.empty()) {
-            return QSize(name_column_width_, 0);
-        }
-    }
-
     return QVariant();
 }
 
@@ -1157,16 +1129,6 @@ void FileTableModel::renameItemNamed(const QString &name, const QString &new_nam
         }
 }
 
-void FileTableModel::onResize(const QSize &size)
-{
-    name_column_width_ = size.width() - kDefaultColumnSum + kFileNameColumnWidth;
-    // name_column_width_ should be always larger than kFileNameColumnWidth
-    if (dirents_.empty())
-        return;
-    emit dataChanged(index(0, FILE_COLUMN_NAME),
-                     index(dirents_.size()-1 , FILE_COLUMN_NAME));
-}
-
 void FileTableModel::updateDownloadInfo()
 {
     FileBrowserDialog *dialog = (FileBrowserDialog *)(QObject::parent());
@@ -1186,7 +1148,6 @@ void FileTableModel::updateDownloadInfo()
                      index(dirents_.size() - 1 , FILE_COLUMN_SIZE));
 }
 
-
 void FileTableModel::updateFileCacheStatus()
 {
     if (dirents_.empty())
