@@ -70,6 +70,7 @@ private:
 };
 
 const int kRefreshReposInterval = 1000 * 60 * 5; // 5 min
+const int kRetryRefreshReposInterval = 1000 * 10; // 10 seconds
 
 bool loadSyncedFolderCB(sqlite3_stmt *stmt, void *data)
 {
@@ -202,8 +203,10 @@ void RepoService::refresh()
 
     const Account *account = &accounts.front();
 
-    if (!account->isValid())
+    if (!account->isValid()) {
+        in_refresh_ = false;
         return;
+    }
 
     in_refresh_ = true;
 
@@ -251,10 +254,8 @@ void RepoService::refresh()
     }
 
     list_repo_req_ = new ListReposRequest(*account);
-
     connect(list_repo_req_, SIGNAL(success(const std::vector<ServerRepo>&)),
             this, SLOT(onRefreshSuccess(const std::vector<ServerRepo>&)));
-
     connect(list_repo_req_, SIGNAL(failed(const ApiError&)),
             this, SLOT(onRefreshFailed(const ApiError&)));
     list_repo_req_->send();
@@ -285,6 +286,39 @@ void RepoService::onRefreshSuccess(const std::vector<ServerRepo>& repos)
             startGetRequestFor(synced_subfolders_[i].repoId());
     }
 
+    if (synced_subfolder_db_) {
+        const Account account = seafApplet->accountManager()->currentAccount();
+        if (!account.isValid()) {
+            return;
+        }
+        for (size_t i = 0; i < local_repos_.size(); ++i) {
+            bool found = false;
+            const LocalRepo& repo = local_repos_[i];
+
+            // skip repos that do not belong to the current account
+            if (repo.account != account) {
+                continue;
+            }
+            for (size_t j = 0; j < server_repos_.size(); ++j) {
+                if (repo.id == server_repos_[j].id) {
+                    found = true;
+                    break;
+                }
+            }
+            // skip synced subfolders
+            for (size_t j = 0; j < synced_subfolders_.size(); ++j) {
+                if (synced_subfolders_[j].repoId() == repo.id) {
+                    found = true;
+                    break;
+                }
+            }
+            if (!found) {
+                qWarning ("unsync local library %s/%s because you don't have permission to access it\n", repo.id.toUtf8().data(), repo.name.toUtf8().data());
+                seafApplet->rpcClient()->unsync(repo.id);
+            }
+        }
+    }
+
     if (get_repo_reqs_.empty())
         emit refreshSuccess(repos);
 }
@@ -314,6 +348,7 @@ void RepoService::onRefreshFailed(const ApiError& error)
         return;
     }
 
+    QTimer::singleShot(kRetryRefreshReposInterval, this, SLOT(refresh()));
     emit refreshFailed(error);
 }
 
