@@ -166,6 +166,8 @@ void CloudView::createAccountView()
 // #endif
     connect(account_view_, SIGNAL(refresh()),
             this, SLOT(onRefreshClicked()));
+    connect(account_view_, SIGNAL(sortOrderUpdated()),
+            this, SLOT(onSortOrderUpdated()));
 }
 
 void CloudView::createTabs()
@@ -289,22 +291,9 @@ void CloudView::onCloseBtnClicked()
 bool CloudView::eventFilter(QObject* obj, QEvent* event)
 {
     if (obj == mHeader) {
-        static QPoint oldPos;
         if (event->type() == QEvent::MouseButtonPress) {
-            QMouseEvent* ev = (QMouseEvent*)event;
-            oldPos = ev->globalPos();
-
-            return true;
-        }
-        else if (event->type() == QEvent::MouseMove) {
-            QMouseEvent* ev = (QMouseEvent*)event;
-            const QPoint delta = ev->globalPos() - oldPos;
-
-            MainWindow* win = seafApplet->mainWindow();
-            win->move(win->x() + delta.x(), win->y() + delta.y());
-
-            oldPos = ev->globalPos();
-            return true;
+            QWindow* win = seafApplet->mainWindow()->windowHandle();
+            win->startSystemMove();
         }
     }
     else if (obj == mDropArea) {
@@ -475,6 +464,11 @@ void CloudView::onRefreshClicked()
     }
 }
 
+void CloudView::onSortOrderUpdated()
+{
+    repos_tab_->refresh();
+}
+
 void CloudView::resizeEvent(QResizeEvent* event)
 {
     if (shouldUseFramelessWindow()) {
